AMQPHelpers.RPC (AMQP Helpers v1.1.1)

A remote procedure call implementation.

This module provide a helper function which implements the RPC pattern using the Direct Reply-to. This allows a client to send a request and receive a response synchronously, without having to manage any response queue.

Link to this section Summary

Link to this section Functions

Link to this function

call(adapter \\ Adapter, connection, exchange, routing_key, payload, options \\ [])

Specs

Executes a remote procedure call.

This function sends the given messages and waits for a response using Direct Reply-to.